﻿#region Copyright Syncfusion Inc. 2001 - 2013
// Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion
using System;
using System.Collections.Generic;
using Syncfusion.Olap.Manager;
using Syncfusion.Olap.Reports;
using System.Windows.Media;
using System.Reflection;
using System.Windows;
using Microsoft.Win32;
using System.Windows.Media.Imaging;
using System.Windows.Controls;
using Syncfusion.Windows.Shared;
using Syncfusion.Olap.Data;

namespace RelationalDemo.ViewModel
{
    /// <summary>
    /// Interaction logic for OlapGrid view.
    /// </summary>
    public class ViewModel : Syncfusion.Windows.Shared.NotificationObject
    {
        #region Members
        /// <summary>
        /// Shared connection string.
        /// </summary>
        public static string ConnectionString;
        #endregion

        #region Constructor
        /// <summary>
        /// Initializes a new instance of the <see cref="ViewModel"/> class.
        /// </summary>
        public ViewModel()
        {
            _olapDataManager = new OlapDataManager();
            _olapDataManager.ItemSource = SalesData.ProductSales.GetSalesData();
            _olapDataManager.SetCurrentReport(CreateOlapReport());
            this.GridDataManager = _olapDataManager;
        }
        #endregion

        #region Properties
        private OlapDataManager _olapDataManager;

        /// <summary>
        /// Gets or sets the grid data manager.
        /// </summary>
        /// <value>The grid data manager.</value>
        public OlapDataManager GridDataManager
        {
            get { return _olapDataManager; }
            set
            {
                RaisePropertyChanged();
                _olapDataManager = value;
            }
        }
        #endregion

        #region Methods
        /// <summary>
        /// Creates the OlapReport.
        /// </summary>
        /// <returns></returns>
        private OlapReport CreateOlapReport()
        {
            OlapReport olapReport = new OlapReport();
            // Specifying the Row Dimension Element
            DimensionElement dimensionElementRow = new DimensionElement();
            dimensionElementRow.Name = "Geography";
            dimensionElementRow.Hierarchy = new HierarchyElement() { Name = "Product Hierarchy" };

            dimensionElementRow.Hierarchy.LevelElements.Add(new LevelElement() { Name = "Product" });
            dimensionElementRow.Hierarchy.LevelElements.Add(new LevelElement() { Name = "Date" });

            // Specifying the Column Dimension Element
            DimensionElement dimensionElementColumn = new DimensionElement();
            dimensionElementColumn.Name = "Geography";
            dimensionElementColumn.Hierarchy = new HierarchyElement() { Name = "Geography Hierarchy" };

            dimensionElementColumn.Hierarchy.LevelElements.Add(new LevelElement() { Name = "Country" });
            dimensionElementColumn.Hierarchy.LevelElements.Add(new LevelElement() { Name = "State" });

            // Specifying the Summary Elements
            SummaryElements summaries = new SummaryElements();
            summaries.Add(new SummaryInfo { Column = "Quantity", Key = "Quantity", Type = SummaryType.Sum });
            summaries.Add(new SummaryInfo { Column = "Amount", Key = "Amount", Type = SummaryType.Sum });

            // Adding the Row Elements
            olapReport.SeriesElements.Add(new Item { ElementValue = summaries });
            olapReport.SeriesElements.Add(new Item { ElementValue = dimensionElementRow });
            // Adding the Column Elements
            olapReport.CategoricalElements.Add(new Item { ElementValue = dimensionElementColumn });
            return olapReport;
        }
        #endregion
    }
}
